From: Greg Kroah-Hartman <gregkh@linuxfoundation.org>
To: stable@vger.kernel.org
Cc: Greg Kroah-Hartman <gregkh@linuxfoundation.org>,
patches@lists.linux.dev, Linus Walleij <linus.walleij@linaro.org>,
Andrew Jeffery <andrew@codeconstruct.com.au>,
Bartosz Golaszewski <bartosz.golaszewski@linaro.org>,
Sasha Levin <sashal@kernel.org>
Subject: [PATCH 6.18 105/277] gpio: rename gpio_chip_hwgpio() to gpiod_hwgpio()
Date: Wed, 8 Apr 2026 20:01:30 +0200 [thread overview]
Message-ID: <20260408175937.793772676@linuxfoundation.org> (raw)
In-Reply-To: <20260408175933.836769063@linuxfoundation.org>
6.18-stable review patch. If anyone has any objections, please let me know.
------------------
From: Bartosz Golaszewski <bartosz.golaszewski@linaro.org>
[ Upstream commit df900536e85819f6168783d5f6b3908d47811fdd ]
This function takes a GPIO descriptor as first argument. Make its naming
consistent with the rest of the GPIO codebase and use the gpiod_ prefix.
Reviewed-by: Linus Walleij <linus.walleij@linaro.org>
Reviewed-by: Andrew Jeffery <andrew@codeconstruct.com.au>
Link: https://lore.kernel.org/r/20251016-aspeed-gpiolib-include-v1-1-31201c06d124@linaro.org
Signed-off-by: Bartosz Golaszewski <bartosz.golaszewski@linaro.org>
Stable-dep-of: 6df6ea4b3d15 ("gpiolib: clear requested flag if line is invalid")
Signed-off-by: Sasha Levin <sashal@kernel.org>
---
drivers/gpio/gpio-aspeed.c | 6 ++---
drivers/gpio/gpiolib-cdev.c | 12 +++++-----
drivers/gpio/gpiolib-sysfs.c | 14 +++++------
drivers/gpio/gpiolib.c | 46 ++++++++++++++++++------------------
drivers/gpio/gpiolib.h | 2 +-
5 files changed, 40 insertions(+), 40 deletions(-)
diff --git a/drivers/gpio/gpiolib-cdev.c b/drivers/gpio/gpiolib-cdev.c
index e76bcbd647539..986312c71678f 100644
--- a/drivers/gpio/gpiolib-cdev.c
+++ b/drivers/gpio/gpiolib-cdev.c
@@ -676,7 +676,7 @@ static enum hte_return process_hw_ts_thread(void *p)
}
le.line_seqno = line->line_seqno;
le.seqno = (lr->num_lines == 1) ? le.line_seqno : line->req_seqno;
- le.offset = gpio_chip_hwgpio(line->desc);
+ le.offset = gpiod_hwgpio(line->desc);
linereq_put_event(lr, &le);
@@ -793,7 +793,7 @@ static irqreturn_t edge_irq_thread(int irq, void *p)
line->line_seqno++;
le.line_seqno = line->line_seqno;
le.seqno = (lr->num_lines == 1) ? le.line_seqno : line->req_seqno;
- le.offset = gpio_chip_hwgpio(line->desc);
+ le.offset = gpiod_hwgpio(line->desc);
linereq_put_event(lr, &le);
@@ -891,7 +891,7 @@ static void debounce_work_func(struct work_struct *work)
lr = line->req;
le.timestamp_ns = line_event_timestamp(line);
- le.offset = gpio_chip_hwgpio(line->desc);
+ le.offset = gpiod_hwgpio(line->desc);
#ifdef CONFIG_HTE
if (edflags & GPIO_V2_LINE_FLAG_EVENT_CLOCK_HTE) {
/* discard events except the last one */
@@ -1591,7 +1591,7 @@ static void linereq_show_fdinfo(struct seq_file *out, struct file *file)
for (i = 0; i < lr->num_lines; i++)
seq_printf(out, "gpio-line:\t%d\n",
- gpio_chip_hwgpio(lr->lines[i].desc));
+ gpiod_hwgpio(lr->lines[i].desc));
}
#endif
@@ -2244,7 +2244,7 @@ static void gpio_desc_to_lineinfo(struct gpio_desc *desc,
return;
memset(info, 0, sizeof(*info));
- info->offset = gpio_chip_hwgpio(desc);
+ info->offset = gpiod_hwgpio(desc);
if (desc->name)
strscpy(info->name, desc->name, sizeof(info->name));
@@ -2550,7 +2550,7 @@ static int lineinfo_changed_notify(struct notifier_block *nb,
struct gpio_desc *desc = data;
struct file *fp;
- if (!test_bit(gpio_chip_hwgpio(desc), cdev->watched_lines))
+ if (!test_bit(gpiod_hwgpio(desc), cdev->watched_lines))
return NOTIFY_DONE;
/* Keep the file descriptor alive for the duration of the notification. */
diff --git a/drivers/gpio/gpiolib-sysfs.c b/drivers/gpio/gpiolib-sysfs.c
index e044690ad412b..d4a46a0a37d8f 100644
--- a/drivers/gpio/gpiolib-sysfs.c
+++ b/drivers/gpio/gpiolib-sysfs.c
@@ -244,7 +244,7 @@ static int gpio_sysfs_request_irq(struct gpiod_data *data, unsigned char flags)
* Remove this redundant call (along with the corresponding unlock)
* when those drivers have been fixed.
*/
- ret = gpiochip_lock_as_irq(guard.gc, gpio_chip_hwgpio(desc));
+ ret = gpiochip_lock_as_irq(guard.gc, gpiod_hwgpio(desc));
if (ret < 0)
goto err_clr_bits;
@@ -258,7 +258,7 @@ static int gpio_sysfs_request_irq(struct gpiod_data *data, unsigned char flags)
return 0;
err_unlock:
- gpiochip_unlock_as_irq(guard.gc, gpio_chip_hwgpio(desc));
+ gpiochip_unlock_as_irq(guard.gc, gpiod_hwgpio(desc));
err_clr_bits:
clear_bit(GPIOD_FLAG_EDGE_RISING, &desc->flags);
clear_bit(GPIOD_FLAG_EDGE_FALLING, &desc->flags);
@@ -280,7 +280,7 @@ static void gpio_sysfs_free_irq(struct gpiod_data *data)
data->irq_flags = 0;
free_irq(data->irq, data);
- gpiochip_unlock_as_irq(guard.gc, gpio_chip_hwgpio(desc));
+ gpiochip_unlock_as_irq(guard.gc, gpiod_hwgpio(desc));
clear_bit(GPIOD_FLAG_EDGE_RISING, &desc->flags);
clear_bit(GPIOD_FLAG_EDGE_FALLING, &desc->flags);
}
@@ -478,10 +478,10 @@ static int export_gpio_desc(struct gpio_desc *desc)
if (!guard.gc)
return -ENODEV;
- offset = gpio_chip_hwgpio(desc);
+ offset = gpiod_hwgpio(desc);
if (!gpiochip_line_is_valid(guard.gc, offset)) {
pr_debug_ratelimited("%s: GPIO %d masked\n", __func__,
- gpio_chip_hwgpio(desc));
+ gpiod_hwgpio(desc));
return -EINVAL;
}
@@ -823,7 +823,7 @@ int gpiod_export(struct gpio_desc *desc, bool direction_may_change)
}
desc_data->chip_attr_group.name = kasprintf(GFP_KERNEL, "gpio%u",
- gpio_chip_hwgpio(desc));
+ gpiod_hwgpio(desc));
if (!desc_data->chip_attr_group.name) {
status = -ENOMEM;
goto err_put_dirent;
@@ -843,7 +843,7 @@ int gpiod_export(struct gpio_desc *desc, bool direction_may_change)
if (status)
goto err_free_name;
- path = kasprintf(GFP_KERNEL, "gpio%u/value", gpio_chip_hwgpio(desc));
+ path = kasprintf(GFP_KERNEL, "gpio%u/value", gpiod_hwgpio(desc));
if (!path) {
status = -ENOMEM;
goto err_remove_groups;
diff --git a/drivers/gpio/gpiolib.c b/drivers/gpio/gpiolib.c
index 4524c89946d7c..497fda9bf8f1e 100644
--- a/drivers/gpio/gpiolib.c
+++ b/drivers/gpio/gpiolib.c
@@ -443,7 +443,7 @@ int gpiod_get_direction(struct gpio_desc *desc)
if (!guard.gc)
return -ENODEV;
- offset = gpio_chip_hwgpio(desc);
+ offset = gpiod_hwgpio(desc);
flags = READ_ONCE(desc->flags);
/*
@@ -2446,7 +2446,7 @@ static int gpiod_request_commit(struct gpio_desc *desc, const char *label)
if (test_and_set_bit(GPIOD_FLAG_REQUESTED, &desc->flags))
return -EBUSY;
- offset = gpio_chip_hwgpio(desc);
+ offset = gpiod_hwgpio(desc);
if (!gpiochip_line_is_valid(guard.gc, offset))
return -EINVAL;
@@ -2508,7 +2508,7 @@ static void gpiod_free_commit(struct gpio_desc *desc)
if (guard.gc && test_bit(GPIOD_FLAG_REQUESTED, &flags)) {
if (guard.gc->free)
- guard.gc->free(guard.gc, gpio_chip_hwgpio(desc));
+ guard.gc->free(guard.gc, gpiod_hwgpio(desc));
clear_bit(GPIOD_FLAG_ACTIVE_LOW, &flags);
clear_bit(GPIOD_FLAG_REQUESTED, &flags);
@@ -2668,7 +2668,7 @@ int gpio_do_set_config(struct gpio_desc *desc, unsigned long config)
if (!guard.gc->set_config)
return -ENOTSUPP;
- ret = guard.gc->set_config(guard.gc, gpio_chip_hwgpio(desc), config);
+ ret = guard.gc->set_config(guard.gc, gpiod_hwgpio(desc), config);
if (ret > 0)
ret = -EBADE;
@@ -2699,7 +2699,7 @@ static int gpio_set_config_with_argument_optional(struct gpio_desc *desc,
u32 argument)
{
struct device *dev = &desc->gdev->dev;
- int gpio = gpio_chip_hwgpio(desc);
+ int gpio = gpiod_hwgpio(desc);
int ret;
ret = gpio_set_config_with_argument(desc, mode, argument);
@@ -2862,9 +2862,9 @@ int gpiod_direction_input_nonotify(struct gpio_desc *desc)
*/
if (guard.gc->direction_input) {
ret = gpiochip_direction_input(guard.gc,
- gpio_chip_hwgpio(desc));
+ gpiod_hwgpio(desc));
} else if (guard.gc->get_direction) {
- dir = gpiochip_get_direction(guard.gc, gpio_chip_hwgpio(desc));
+ dir = gpiochip_get_direction(guard.gc, gpiod_hwgpio(desc));
if (dir < 0)
return dir;
@@ -2923,12 +2923,12 @@ static int gpiod_direction_output_raw_commit(struct gpio_desc *desc, int value)
if (guard.gc->direction_output) {
ret = gpiochip_direction_output(guard.gc,
- gpio_chip_hwgpio(desc), val);
+ gpiod_hwgpio(desc), val);
} else {
/* Check that we are in output mode if we can */
if (guard.gc->get_direction) {
dir = gpiochip_get_direction(guard.gc,
- gpio_chip_hwgpio(desc));
+ gpiod_hwgpio(desc));
if (dir < 0)
return dir;
@@ -2943,7 +2943,7 @@ static int gpiod_direction_output_raw_commit(struct gpio_desc *desc, int value)
* If we can't actively set the direction, we are some
* output-only chip, so just drive the output as desired.
*/
- ret = gpiochip_set(guard.gc, gpio_chip_hwgpio(desc), val);
+ ret = gpiochip_set(guard.gc, gpiod_hwgpio(desc), val);
if (ret)
return ret;
}
@@ -3094,7 +3094,7 @@ int gpiod_enable_hw_timestamp_ns(struct gpio_desc *desc, unsigned long flags)
}
ret = guard.gc->en_hw_timestamp(guard.gc,
- gpio_chip_hwgpio(desc), flags);
+ gpiod_hwgpio(desc), flags);
if (ret)
gpiod_warn(desc, "%s: hw ts request failed\n", __func__);
@@ -3126,7 +3126,7 @@ int gpiod_disable_hw_timestamp_ns(struct gpio_desc *desc, unsigned long flags)
return -ENOTSUPP;
}
- ret = guard.gc->dis_hw_timestamp(guard.gc, gpio_chip_hwgpio(desc),
+ ret = guard.gc->dis_hw_timestamp(guard.gc, gpiod_hwgpio(desc),
flags);
if (ret)
gpiod_warn(desc, "%s: hw ts release failed\n", __func__);
@@ -3261,7 +3261,7 @@ static int gpiochip_get(struct gpio_chip *gc, unsigned int offset)
static int gpio_chip_get_value(struct gpio_chip *gc, const struct gpio_desc *desc)
{
- return gc->get ? gpiochip_get(gc, gpio_chip_hwgpio(desc)) : -EIO;
+ return gc->get ? gpiochip_get(gc, gpiod_hwgpio(desc)) : -EIO;
}
/* I/O calls are only valid after configuration completed; the relevant
@@ -3421,7 +3421,7 @@ int gpiod_get_array_value_complex(bool raw, bool can_sleep,
first = i;
do {
const struct gpio_desc *desc = desc_array[i];
- int hwgpio = gpio_chip_hwgpio(desc);
+ int hwgpio = gpiod_hwgpio(desc);
__set_bit(hwgpio, mask);
i++;
@@ -3443,7 +3443,7 @@ int gpiod_get_array_value_complex(bool raw, bool can_sleep,
for (j = first; j < i; ) {
const struct gpio_desc *desc = desc_array[j];
- int hwgpio = gpio_chip_hwgpio(desc);
+ int hwgpio = gpiod_hwgpio(desc);
int value = test_bit(hwgpio, bits);
if (!raw && test_bit(GPIOD_FLAG_ACTIVE_LOW, &desc->flags))
@@ -3580,7 +3580,7 @@ EXPORT_SYMBOL_GPL(gpiod_get_array_value);
*/
static int gpio_set_open_drain_value_commit(struct gpio_desc *desc, bool value)
{
- int ret = 0, offset = gpio_chip_hwgpio(desc);
+ int ret = 0, offset = gpiod_hwgpio(desc);
CLASS(gpio_chip_guard, guard)(desc);
if (!guard.gc)
@@ -3609,7 +3609,7 @@ static int gpio_set_open_drain_value_commit(struct gpio_desc *desc, bool value)
*/
static int gpio_set_open_source_value_commit(struct gpio_desc *desc, bool value)
{
- int ret = 0, offset = gpio_chip_hwgpio(desc);
+ int ret = 0, offset = gpiod_hwgpio(desc);
CLASS(gpio_chip_guard, guard)(desc);
if (!guard.gc)
@@ -3641,7 +3641,7 @@ static int gpiod_set_raw_value_commit(struct gpio_desc *desc, bool value)
return -ENODEV;
trace_gpio_value(desc_to_gpio(desc), 0, value);
- return gpiochip_set(guard.gc, gpio_chip_hwgpio(desc), value);
+ return gpiochip_set(guard.gc, gpiod_hwgpio(desc), value);
}
/*
@@ -3764,7 +3764,7 @@ int gpiod_set_array_value_complex(bool raw, bool can_sleep,
do {
struct gpio_desc *desc = desc_array[i];
- int hwgpio = gpio_chip_hwgpio(desc);
+ int hwgpio = gpiod_hwgpio(desc);
int value = test_bit(i, value_bitmap);
if (unlikely(!test_bit(GPIOD_FLAG_IS_OUT, &desc->flags)))
@@ -4004,7 +4004,7 @@ int gpiod_to_irq(const struct gpio_desc *desc)
if (!gc)
return -ENODEV;
- offset = gpio_chip_hwgpio(desc);
+ offset = gpiod_hwgpio(desc);
if (gc->to_irq) {
ret = gc->to_irq(gc, offset);
if (ret)
@@ -4961,7 +4961,7 @@ int gpiod_hog(struct gpio_desc *desc, const char *name,
if (test_and_set_bit(GPIOD_FLAG_IS_HOGGED, &desc->flags))
return 0;
- hwnum = gpio_chip_hwgpio(desc);
+ hwnum = gpiod_hwgpio(desc);
local_desc = gpiochip_request_own_desc(guard.gc, hwnum, name,
lflags, dflags);
@@ -5042,7 +5042,7 @@ struct gpio_descs *__must_check gpiod_get_array(struct device *dev,
* If pin hardware number of array member 0 is also 0, select
* its chip as a candidate for fast bitmap processing path.
*/
- if (descs->ndescs == 0 && gpio_chip_hwgpio(desc) == 0) {
+ if (descs->ndescs == 0 && gpiod_hwgpio(desc) == 0) {
struct gpio_descs *array;
bitmap_size = BITS_TO_LONGS(gdev->ngpio > count ?
@@ -5087,7 +5087,7 @@ struct gpio_descs *__must_check gpiod_get_array(struct device *dev,
* Detect array members which belong to the 'fast' chip
* but their pins are not in hardware order.
*/
- else if (gpio_chip_hwgpio(desc) != descs->ndescs) {
+ else if (gpiod_hwgpio(desc) != descs->ndescs) {
/*
* Don't use fast path if all array members processed so
* far belong to the same chip as this one but its pin
diff --git a/drivers/gpio/gpiolib.h b/drivers/gpio/gpiolib.h
index 6ee29d0222393..2b4f479d32123 100644
--- a/drivers/gpio/gpiolib.h
+++ b/drivers/gpio/gpiolib.h
@@ -276,7 +276,7 @@ const char *gpiod_get_label(struct gpio_desc *desc);
/*
* Return the GPIO number of the passed descriptor relative to its chip
*/
-static inline int gpio_chip_hwgpio(const struct gpio_desc *desc)
+static inline int gpiod_hwgpio(const struct gpio_desc *desc)
{
return desc - &desc->gdev->descs[0];
}
diff --git a/drivers/gpio/gpio-aspeed.c b/drivers/gpio/gpio-aspeed.c
index 7953a9c4e36d7..3da37a0fda3fb 100644
--- a/drivers/gpio/gpio-aspeed.c
+++ b/drivers/gpio/gpio-aspeed.c
@@ -24,7 +24,7 @@
/*
* These two headers aren't meant to be used by GPIO drivers. We need
* them in order to access gpio_chip_hwgpio() which we need to implement
* the aspeed specific API which allows the coprocessor to request
* access to some GPIOs and to arbitrate between coprocessor and ARM.
*/
@@ -942,7 +942,7 @@ int aspeed_gpio_copro_grab_gpio(struct gpio_desc *desc,
{
struct gpio_chip *chip = gpiod_to_chip(desc);
struct aspeed_gpio *gpio = gpiochip_get_data(chip);
- int rc = 0, bindex, offset = gpio_chip_hwgpio(desc);
+ int rc = 0, bindex, offset = gpiod_hwgpio(desc);
const struct aspeed_gpio_bank *bank = to_bank(offset);
if (!aspeed_gpio_support_copro(gpio))
@@ -987,7 +987,7 @@ int aspeed_gpio_copro_release_gpio(struct gpio_desc *desc)
{
struct gpio_chip *chip = gpiod_to_chip(desc);
struct aspeed_gpio *gpio = gpiochip_get_data(chip);
- int rc = 0, bindex, offset = gpio_chip_hwgpio(desc);
+ int rc = 0, bindex, offset = gpiod_hwgpio(desc);
if (!aspeed_gpio_support_copro(gpio))
return -EOPNOTSUPP;
@@ -24,7 +24,7 @@
/*
* These two headers aren't meant to be used by GPIO drivers. We need
- * them in order to access gpio_chip_hwgpio() which we need to implement
+ * them in order to access gpiod_hwgpio() which we need to implement
* the aspeed specific API which allows the coprocessor to request
* access to some GPIOs and to arbitrate between coprocessor and ARM.
--
2.53.0
next prev parent reply other threads:[~2026-04-08 18:31 UTC|newest]
Thread overview: 284+ messages / expand[flat|nested] mbox.gz Atom feed top
2026-04-08 17:59 [PATCH 6.18 000/277] 6.18.22-rc1 review Greg Kroah-Hartman
2026-04-08 17:59 ` [PATCH 6.18 001/277] arm64/scs: Fix handling of advance_loc4 Greg Kroah-Hartman
2026-04-08 17:59 ` [PATCH 6.18 002/277] HID: logitech-hidpp: Enable MX Master 4 over bluetooth Greg Kroah-Hartman
2026-04-08 17:59 ` [PATCH 6.18 003/277] wifi: mac80211: check tdls flag in ieee80211_tdls_oper Greg Kroah-Hartman
2026-04-08 17:59 ` [PATCH 6.18 004/277] HID: wacom: fix out-of-bounds read in wacom_intuos_bt_irq Greg Kroah-Hartman
2026-04-08 17:59 ` [PATCH 6.18 005/277] atm: lec: fix use-after-free in sock_def_readable() Greg Kroah-Hartman
2026-04-08 17:59 ` [PATCH 6.18 006/277] btrfs: dont take device_list_mutex when querying zone info Greg Kroah-Hartman
2026-04-08 17:59 ` [PATCH 6.18 007/277] tg3: replace placeholder MAC address with device property Greg Kroah-Hartman
2026-04-08 17:59 ` [PATCH 6.18 008/277] objtool: Fix Clang jump table detection Greg Kroah-Hartman
2026-04-08 17:59 ` [PATCH 6.18 009/277] HID: logitech-hidpp: Prevent use-after-free on force feedback initialisation failure Greg Kroah-Hartman
2026-04-08 17:59 ` [PATCH 6.18 010/277] HID: core: Mitigate potential OOB by removing bogus memset() Greg Kroah-Hartman
2026-04-08 17:59 ` [PATCH 6.18 011/277] HID: multitouch: Check to ensure report responses match the request Greg Kroah-Hartman
2026-04-08 17:59 ` [PATCH 6.18 012/277] btrfs: reserve enough transaction items for qgroup ioctls Greg Kroah-Hartman
2026-04-08 17:59 ` [PATCH 6.18 013/277] i2c: tegra: Dont mark devices with pins as IRQ safe Greg Kroah-Hartman
2026-04-08 17:59 ` [PATCH 6.18 014/277] btrfs: reject root items with drop_progress and zero drop_level Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 015/277] smb: client: fix generic/694 due to wrong ->i_blocks Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 016/277] spi: geni-qcom: Check DMA interrupts early in ISR Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 017/277] dt-bindings: auxdisplay: ht16k33: Use unevaluatedProperties to fix common property warning Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 018/277] wifi: iwlwifi: fix remaining kernel-doc warnings Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 019/277] wifi: iwlwifi: mld: Fix MLO scan timing Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 020/277] wifi: iwlwifi: mvm: dont send a 6E related command when not supported Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 021/277] wifi: iwlwifi: cfg: add new device names Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 022/277] wifi: iwlwifi: disable EHT if the device doesnt allow it Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 023/277] wifi: iwlwifi: mld: correctly set wifi generation data Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 024/277] wifi: ath11k: Pass the correct value of each TID during a stop AMPDU session Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 025/277] crypto: caam - fix DMA corruption on long hmac keys Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 026/277] crypto: caam - fix overflow " Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 027/277] crypto: deflate - fix spurious -ENOSPC Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 028/277] crypto: af-alg - fix NULL pointer dereference in scatterwalk Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 029/277] net: mana: Fix RX skb truesize accounting Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 030/277] netdevsim: fix build if SKB_EXTENSIONS=n Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 031/277] net: fec: fix the PTP periodic output sysfs interface Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 032/277] net: enetc: reset PIR and CIR if they are not equal when initializing TX ring Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 033/277] net: qrtr: replace qrtr_tx_flow radix_tree with xarray to fix memory leak Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 034/277] net: ipv6: ndisc: fix ndisc_ra_useropt to initialize nduseropt_padX fields to zero to prevent an info-leak Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 035/277] net/ipv6: ioam6: prevent schema length wraparound in trace fill Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 036/277] tg3: Fix race for querying speed/duplex Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 037/277] ipv6: icmp: clear skb2->cb[] in ip6_err_gen_icmpv6_unreach() Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 038/277] ip6_tunnel: clear skb2->cb[] in ip4ip6_err() Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 039/277] eth: fbnic: Account for page fragments when updating BDQ tail Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 040/277] bridge: br_nd_send: linearize skb before parsing ND options Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 041/277] net/sched: sch_hfsc: fix divide-by-zero in rtsc_min() Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 042/277] net: sfp: Fix Ubiquiti U-Fiber Instant SFP module on mvneta Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 043/277] net: enetc: check whether the RSS algorithm is Toeplitz Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 044/277] net: enetc: do not allow VF to configure the RSS key Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 045/277] ALSA: usb-audio: Exclude Scarlett Solo 1st Gen from SKIP_IFACE_SETUP Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 046/277] ASoC: ep93xx: Fix unchecked clk_prepare_enable() and add rollback on failure Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 047/277] ipv6: prevent possible UaF in addrconf_permanent_addr() Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 048/277] net: airoha: Add missing cleanup bits in airoha_qdma_cleanup_rx_queue() Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 049/277] net: introduce mangleid_features Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 050/277] net: use skb_header_pointer() for TCPv4 GSO frag_off check Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 051/277] net: sched: cls_api: fix tc_chain_fill_node to initialize tcm_info to zero to prevent an info-leak Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 052/277] bnxt_en: set backing store type from query type Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 053/277] crypto: algif_aead - Revert to operating out-of-place Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 054/277] crypto: authencesn - Do not place hiseq at end of dst for out-of-place decryption Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 055/277] net: bonding: fix use-after-free in bond_xmit_broadcast() Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 056/277] NFC: pn533: bound the UART receive buffer Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 057/277] net: xilinx: axienet: Correct BD length masks to match AXIDMA IP spec Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 058/277] net: xilinx: axienet: Fix BQL accounting for multi-BD TX packets Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 059/277] ASoC: Intel: boards: fix unmet dependency on PINCTRL Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 060/277] bpf: Fix regsafe() for pointers to packet Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 061/277] net: ipv6: flowlabel: defer exclusive option free until RCU teardown Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 062/277] mptcp: add eat_recv_skb helper Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 063/277] mptcp: fix soft lockup in mptcp_recvmsg() Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 064/277] net: stmmac: skip VLAN restore when VLAN hash ops are missing Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 065/277] ALSA: usb-audio: Exclude Scarlett 2i2 1st Gen (8016) from SKIP_IFACE_SETUP Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 066/277] netfilter: flowtable: strictly check for maximum number of actions Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 067/277] netfilter: nfnetlink_log: account for netlink header size Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 068/277] netfilter: x_tables: ensure names are nul-terminated Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 069/277] netfilter: ipset: use nla_strcmp for IPSET_ATTR_NAME attr Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 070/277] netfilter: nf_conntrack_helper: pass helper to expect cleanup Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 071/277] netfilter: ctnetlink: zero expect NAT fields when CTA_EXPECT_NAT absent Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 072/277] netfilter: nf_conntrack_expect: honor expectation helper field Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 073/277] netfilter: nf_conntrack_expect: use expect->helper Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.18 074/277] netfilter: nf_conntrack_expect: store netns and zone in expectation Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 075/277] netfilter: ctnetlink: ignore explicit helper on new expectations Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 076/277] netfilter: x_tables: restrict xt_check_match/xt_check_target extensions for NFPROTO_ARP Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 077/277] netfilter: nf_tables: reject immediate NF_QUEUE verdict Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 078/277] Bluetooth: hci_sync: call destroy in hci_cmd_sync_run if immediate Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 079/277] Bluetooth: SCO: fix race conditions in sco_sock_connect() Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 080/277] Bluetooth: hci_h4: Fix race during initialization Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 081/277] Bluetooth: MGMT: validate LTK enc_size on load Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 082/277] Bluetooth: hci_conn: fix potential UAF in set_cig_params_sync Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 083/277] Bluetooth: hci_event: fix potential UAF in hci_le_remote_conn_param_req_evt Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 084/277] Bluetooth: MGMT: validate mesh send advertising payload length Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 085/277] rds: ib: reject FRMR registration before IB connection is established Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 086/277] bpf: sockmap: Fix use-after-free of sk->sk_socket in sk_psock_verdict_data_ready() Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 087/277] net/sched: sch_netem: fix out-of-bounds access in packet corruption Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 088/277] net: macb: fix clk handling on PCI glue driver removal Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 089/277] net: macb: properly unregister fixed rate clocks Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 090/277] net/mlx5: lag: Check for LAG device before creating debugfs Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 091/277] net/mlx5: Avoid "No data available" when FW version queries fail Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 092/277] net/mlx5: Fix switchdev mode rollback in case of failure Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 093/277] bnxt_en: Restore default stat ctxs for ULP when resource is available Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 094/277] net/x25: Fix potential double free of skb Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 095/277] net/x25: Fix overflow when accumulating packets Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 096/277] net/sched: cls_fw: fix NULL pointer dereference on shared blocks Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 097/277] net/sched: cls_flow: " Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 098/277] net: hsr: fix VLAN add unwind on slave errors Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 099/277] ipv6: avoid overflows in ip6_datagram_send_ctl() Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 100/277] eth: fbnic: Increase FBNIC_QUEUE_SIZE_MIN to 64 Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 101/277] bpf: reject direct access to nullable PTR_TO_BUF pointers Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 102/277] bpf: Reject sleepable kprobe_multi programs at attach time Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 103/277] Revert "drm: Fix use-after-free on framebuffers and property blobs when calling drm_dev_unplug" Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 104/277] iio: imu: bno055: fix BNO055_SCAN_CH_COUNT off by one Greg Kroah-Hartman
2026-04-08 18:01 ` Greg Kroah-Hartman [this message]
2026-04-08 18:01 ` [PATCH 6.18 106/277] gpiolib: clear requested flag if line is invalid Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 107/277] accel/qaic: Handle DBC deactivation if the owner went away Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 108/277] io_uring/rsrc: reject zero-length fixed buffer import Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 109/277] hwmon: (tps53679) Fix array access with zero-length block read Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 110/277] hwmon: (pxe1610) Check return value of page-select write in probe Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 111/277] hwmon: (ltc4286) Add missing MODULE_IMPORT_NS("PMBUS") Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 112/277] dt-bindings: gpio: fix microchip #interrupt-cells Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 113/277] spi: stm32-ospi: Fix resource leak in remove() callback Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 114/277] spi: stm32-ospi: Fix reset control leak on probe error Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 115/277] drm/xe/pxp: Clean up termination status on failure Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 116/277] drm/xe/pxp: Remove incorrect handling of impossible state during suspend Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 117/277] drm/xe/pxp: Clear restart flag in pxp_start after jumping back Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 118/277] hwmon: (tps53679) Fix device ID comparison and printing in tps53676_identify() Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 119/277] spi: amlogic: spifc-a4: unregister ECC engine on probe failure and remove() callback Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 120/277] hwmon: (occ) Fix missing newline in occ_show_extended() Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 121/277] drm/sysfb: Fix efidrm error handling and memory type mismatch Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 122/277] hwmon: (asus-ec-sensors) Fix T_Sensor for PRIME X670E-PRO WIFI Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 123/277] mips: ralink: update CPU clock index Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 124/277] sched/fair: Fix zero_vruntime tracking fix Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 125/277] perf/x86: Fix potential bad container_of in intel_pmu_hw_config Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 126/277] riscv: kgdb: fix several debug register assignment bugs Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 127/277] riscv: Reset pmm when PR_TAGGED_ADDR_ENABLE is not set Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 128/277] ACPI: RIMT: Add dependency between iommu and devices Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 129/277] drm/ioc32: stop speculation on the drm_compat_ioctl path Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 130/277] rust_binder: use AssertSync for BINDER_VM_OPS Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 131/277] wifi: wilc1000: fix u8 overflow in SSID scan buffer size calculation Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 132/277] wifi: iwlwifi: mvm: fix potential out-of-bounds read in iwl_mvm_nd_match_info_handler() Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 133/277] USB: serial: option: add MeiG Smart SRM825WN Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.18 134/277] drm/amd/display: Fix NULL pointer dereference in dcn401_init_hw() Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 135/277] sched_ext: Fix inconsistent NUMA node lookup in scx_select_cpu_dfl() Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 136/277] lib/crypto: chacha: Zeroize permuted_state before it leaves scope Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 137/277] ALSA: caiaq: fix stack out-of-bounds read in init_card Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 138/277] ALSA: ctxfi: Fix missing SPDIFI1 index handling Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 139/277] ALSA: hda/realtek: Add quirk for ASUS ROG Strix SCAR 15 Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 140/277] ALSA: hda/realtek: add quirk for HP Victus 15-fb0xxx Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 141/277] io_uring/net: fix slab-out-of-bounds read in io_bundle_nbufs() Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 142/277] Bluetooth: SMP: derive legacy responder STK authentication from MITM state Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 143/277] Bluetooth: SMP: force responder MITM requirements before building the pairing response Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 144/277] Bluetooth: hci_sync: fix stack buffer overflow in hci_le_big_create_sync Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 145/277] ksmbd: fix OOB write in QUERY_INFO for compound requests Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 146/277] MIPS: SiByte: Bring back cache initialisation Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 147/277] MIPS: Fix the GCC version check for `__multi3 workaround Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 148/277] hwmon: (occ) Fix division by zero in occ_show_power_1() Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 149/277] mips: mm: Allocate tlb_vpn array atomically Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 150/277] x86/kexec: Disable KCOV instrumentation after load_segments() Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 151/277] drm/amdgpu: fix the idr allocation flags Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 152/277] gpib: fix use-after-free in IO ioctl handlers Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 153/277] iio: add IIO_DECLARE_QUATERNION() macro Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 154/277] iio: orientation: hid-sensor-rotation: fix quaternion alignment Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 155/277] iio: orientation: hid-sensor-rotation: add timestamp hack to not break userspace Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 156/277] iio: adc: ti-adc161s626: fix buffer read on big-endian Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 157/277] iio: adc: ti-adc161s626: use DMA-safe memory for spi_read() Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 158/277] iio: adc: ti-ads1119: Fix unbalanced pm reference count in ds1119_single_conversion() Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 159/277] iio: adc: ti-ads1119: Reinit completion before wait_for_completion_timeout() Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 160/277] iio: adc: ti-ads1119: Replace IRQF_ONESHOT with IRQF_NO_THREAD Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 161/277] drm/ast: dp501: Fix initialization of SCU2C Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 162/277] drm/i915/dsi: Dont do DSC horizontal timing adjustments in command mode Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 163/277] drm/i915/dp: Use crtc_state->enhanced_framing properly on ivb/hsw CPU eDP Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 164/277] drm/amdgpu: Fix wait after reset sequence in S4 Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 165/277] drm/amdgpu: validate doorbell_offset in user queue creation Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 166/277] drm/amdgpu: Change AMDGPU_VA_RESERVED_TRAP_SIZE to 64KB Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 167/277] drm/amdgpu/pm: drop SMU driver if version not matched messages Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 168/277] USB: serial: io_edgeport: add support for Blackbox IC135A Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 169/277] USB: serial: option: add support for Rolling Wireless RW135R-GL Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 170/277] USB: core: add NO_LPM quirk for Razer Kiyo Pro webcam Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 171/277] Input: synaptics-rmi4 - fix a locking bug in an error path Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 172/277] Input: i8042 - add TUXEDO InfinityBook Max 16 Gen10 AMD to i8042 quirk table Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 173/277] Input: bcm5974 - recover from failed mode switch Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 174/277] Input: xpad - add support for BETOP BTP-KP50B/C controllers wireless mode Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 175/277] Input: xpad - add support for Razer Wolverine V3 Pro Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 176/277] iio: adc: ti-ads7950: normalize return value of gpio_get Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 177/277] iio: adc: ti-ads7950: do not clobber gpio state in ti_ads7950_get() Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 178/277] iio: adc: ade9000: fix wrong return type in streaming push Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 179/277] iio: adc: ade9000: fix wrong register in CALIBBIAS case for active power Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 180/277] iio: adc: ade9000: move mutex init before IRQ registration Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 181/277] iio: adc: aspeed: clear reference voltage bits before configuring vref Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 182/277] iio: accel: fix ADXL355 temperature signature value Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 183/277] iio: accel: adxl380: fix FIFO watermark bit 8 always written as 0 Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 184/277] iio: accel: adxl313: add missing error check in predisable Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 185/277] iio: dac: ad5770r: fix error return in ad5770r_read_raw() Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 186/277] iio: imu: adis16550: fix swapped gyro/accel filter functions Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 187/277] iio: light: vcnl4035: fix scan buffer on big-endian Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 188/277] iio: light: veml6070: fix veml6070_read() return value Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 189/277] iio: imu: bmi160: Remove potential undefined behavior in bmi160_config_pin() Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 190/277] iio: imu: st_lsm6dsx: Set FIFO ODR for accelerometer and gyroscope only Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 191/277] iio: gyro: mpu3050: Fix incorrect free_irq() variable Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 192/277] iio: gyro: mpu3050: Fix irq resource leak Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 193/277] iio: gyro: mpu3050: Move iio_device_register() to correct location Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.18 194/277] iio: gyro: mpu3050: Fix out-of-sequence free_irq() Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 195/277] mei: me: reduce the scope on unexpected reset Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 196/277] gpib: lpvo_usb: fix memory leak on disconnect Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 197/277] usb: quirks: add DELAY_INIT quirk for another Silicon Motion flash drive Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 198/277] usb: ulpi: fix double free in ulpi_register_interface() error path Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 199/277] usb: usbtmc: Flush anchored URBs in usbtmc_release Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 200/277] usb: misc: usbio: Fix URB memory leak on submit failure Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 201/277] usb: host: xhci-sideband: delegate offload_usage tracking to class drivers Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 202/277] usb: ehci-brcm: fix sleep during atomic Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 203/277] usb: dwc2: gadget: Fix spin_lock/unlock mismatch in dwc2_hsotg_udc_stop() Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 204/277] usb: core: phy: avoid double use of usb3-phy Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 205/277] usb: cdns3: gadget: fix NULL pointer dereference in ep_queue Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 206/277] usb: cdns3: gadget: fix state inconsistency on gadget init failure Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 207/277] usb: core: use dedicated spinlock for offload state Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 208/277] x86/platform/geode: Fix on-stack property data use-after-return bug Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 209/277] io_uring: protect remaining lockless ctx->rings accesses with RCU Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 210/277] ASoC: qcom: sc7280: make use of common helpers Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 211/277] bridge: br_nd_send: validate ND option lengths Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 212/277] cdc-acm: new quirk for EPSON HMD Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 213/277] comedi: dt2815: add hardware detection to prevent crash Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 214/277] comedi: Reinit dev->spinlock between attachments to low-level drivers Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 215/277] comedi: ni_atmio16d: Fix invalid clean-up after failed attach Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 216/277] comedi: me_daq: Fix potential overrun of firmware buffer Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 217/277] comedi: me4000: " Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 218/277] firmware: microchip: fail auto-update probe if no flash found Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 219/277] dt-bindings: connector: add pd-disable dependency Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 220/277] spi: cadence-qspi: Fix exec_mem_op error handling Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 221/277] s390/zcrypt: Fix memory leak with CCA cards used as accelerator Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 222/277] s390/cpum_sf: Cap sampling rate to prevent lsctl exception Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 223/277] nvmem: imx: assign nvmem_cell_info::raw_len Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 224/277] nvmem: zynqmp_nvmem: Fix buffer size in DMA and memcpy Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 225/277] netfilter: ipset: drop logically empty buckets in mtype_del Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 226/277] gpib: Fix fluke driver s390 compile issue Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 227/277] vt: discard stale unicode buffer on alt screen exit after resize Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 228/277] vt: resize saved " Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 229/277] counter: rz-mtu3-cnt: prevent counter from being toggled multiple times Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 230/277] counter: rz-mtu3-cnt: do not use struct rz_mtu3_channels dev member Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 231/277] crypto: tegra - Add missing CRYPTO_ALG_ASYNC Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 232/277] vxlan: validate ND option lengths in vxlan_na_create Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 233/277] net: ftgmac100: fix ring allocation unwind on open failure Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 234/277] net: ethernet: mtk_ppe: avoid NULL deref when gmac0 is disabled Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 235/277] virtio_net: clamp rss_max_key_size to NETDEV_RSS_KEY_LEN Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 236/277] cpufreq: governor: fix double free in cpufreq_dbs_governor_init() error path Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 237/277] sched_ext: Fix is_bpf_migration_disabled() false negative on non-PREEMPT_RCU Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 238/277] gpio: mxc: map Both Edge pad wakeup to Rising Edge Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 239/277] gpio: Fix resource leaks on errors in gpiochip_add_data_with_key() Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 240/277] thermal: core: Address thermal zone removal races with resume Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 241/277] thermal: core: Fix thermal zone device registration error path Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 242/277] misc: fastrpc: possible double-free of cctx->remote_heap Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 243/277] misc: fastrpc: check qcom_scm_assign_mem() return in rpmsg_probe Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 244/277] usb: typec: thunderbolt: Set enter_vdo during initialization Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 245/277] thunderbolt: Fix property read in nhi_wake_supported() Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 246/277] USB: dummy-hcd: Fix locking/synchronization error Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 247/277] USB: dummy-hcd: Fix interrupt synchronization error Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 248/277] usb: gadget: dummy_hcd: fix premature URB completion when ZLP follows partial transfer Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 249/277] usb: typec: ucsi: validate connector number in ucsi_notify_common() Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 250/277] HID: appletb-kbd: add .resume method in PM Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 251/277] ice: Fix memory leak in ice_set_ringparam() Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 252/277] usb: gadget: u_ether: Fix race between gether_disconnect and eth_stop Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 253/277] usb: gadget: u_ether: Fix NULL pointer deref in eth_get_drvinfo Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.18 254/277] usb: gadget: uvc: fix NULL pointer dereference during unbind race Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.18 255/277] usb: gadget: f_subset: Fix unbalanced refcnt in geth_free Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.18 256/277] usb: gadget: f_rndis: Protect RNDIS options with mutex Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.18 257/277] usb: gadget: f_ecm: Fix net_device lifecycle with device_move Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.18 258/277] usb: gadget: f_eem: " Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.18 259/277] usb: gadget: f_subset: " Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.18 260/277] usb: gadget: f_rndis: " Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.18 261/277] usb: gadget: f_hid: move list and spinlock inits from bind to alloc Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.18 262/277] usb: gadget: f_uac1_legacy: validate control request size Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.18 263/277] kallsyms: clean up @namebuf initialization in kallsyms_lookup_buildid() Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.18 264/277] kallsyms: clean up modname and modbuildid " Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.18 265/277] kallsyms: cleanup code for appending the module buildid Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.18 266/277] kallsyms: prevent module removal when printing module name and buildid Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.18 267/277] wifi: virt_wifi: remove SET_NETDEV_DEV to avoid use-after-free Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.18 268/277] drm/amd/pm: disable OD_FAN_CURVE if temp or pwm range invalid for smu v13 Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.18 269/277] drm/amd/display: Fix DCE LVDS handling Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.18 270/277] net: mana: fix use-after-free in add_adev() error path Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.18 271/277] net: correctly handle tunneled traffic on IPV6_CSUM GSO fallback Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.18 272/277] scsi: target: file: Use kzalloc_flex for aio_cmd Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.18 273/277] scsi: target: tcm_loop: Drain commands in target_reset handler Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.18 274/277] mm: replace READ_ONCE() with standard page table accessors Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.18 275/277] mm/memory: fix PMD/PUD checks in follow_pfnmap_start() Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.18 276/277] sched_ext: Refactor do_enqueue_task() local and global DSQ paths Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.18 277/277] sched_ext: Fix stale direct dispatch state in ddsp_dsq_id Greg Kroah-Hartman
2026-04-08 21:27 ` [PATCH 6.18 000/277] 6.18.22-rc1 review Dileep malepu
2026-04-09 6:16 ` Shung-Hsi Yu
2026-04-09 7:23 ` Pavel Machek
2026-04-09 8:03 ` Ron Economos
2026-04-09 9:01 ` Wentao Guan
2026-04-09 9:04 ` Jon Hunter
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20260408175937.793772676@linuxfoundation.org \
--to=gregkh@linuxfoundation.org \
--cc=andrew@codeconstruct.com.au \
--cc=bartosz.golaszewski@linaro.org \
--cc=linus.walleij@linaro.org \
--cc=patches@lists.linux.dev \
--cc=sashal@kernel.org \
--cc=stable@vger.kernel.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox